WebMotion class

The Web implementation of MotionPlatform.

Inheritance
  • Object
  • PlatformInterface
  • MotionPlatform
  • WebMotion

Constructors

WebMotion()

Properties

gyroscopeStream Stream<MotionEvent>?
The gyroscope stream, if available.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
isGradientOverlayAvailable bool
Indicates whether the gradient is available.
no setterinherited
isGyroscopeAvailable bool
Indicates whether the gyroscope is available.
no setteroverride
isPermissionGranted bool
Indicates whether the permission is granted.
no setteroverride
isPermissionRequired bool
Indicates whether a permission is required to access gyroscope data.
no setteroverride
isSafariMobile bool
Platform features declaration Detects if the platform is Safari Mobile (iOS or iPad).
no setteroverride
lastDeviceMotionEvent DateTime
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updateInterval → FramesPerSecond
The interval at which the gyroscope stream is updated.
no setterinherited

Methods

initialize() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDeviceMotion(JSObject e) → void
requestPermission() Future<bool>
override
setUpdateInterval(FramesPerSecond updateInterval) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void
Factory method that initializes the Motion plugin platform with an instance of the plugin for the web.