registerWith static method
Factory method that initializes the Motion plugin platform with an instance of the plugin for the web.
Implementation
static void registerWith(Registrar registrar) {
MotionPlatform.instance = WebMotion();
}
Factory method that initializes the Motion plugin platform with an instance of the plugin for the web.
static void registerWith(Registrar registrar) {
MotionPlatform.instance = WebMotion();
}